Compute confidence interval/s for the log-odds parameters
estimate_ci_logodds(
logodds_est,
cdf_est,
out_form,
covar,
treat_prob_est,
treat,
treat_form,
out,
ci,
alpha = 0.05,
nboot,
out_levels,
out_model,
...
)The point estimates for log-odds.
A list of treatment-specific CDF estimates.
The right-hand side of a regression formula for the working proportional odds model. NOTE: THIS FORMULA MUST NOT SUPPRESS THE INTERCEPT.
A data.frame containing the covariates to include in the working
proportional odds model.
Estimated probability of treatments, output from call
to estimate_treat_prob.
A numeric vector containing treatment status. Should only assume
a value 0 or 1.
The right-hand side of a regression formula for the working model of treatment probability as a function of covariates
A numeric vector containing the outcomes. Missing outcomes are
allowed.
A vector of characters indicating which confidence intervals
should be computed ("bca" and/or "wald")
Confidence intervals have nominal level 1-alpha.
Number of bootstrap replicates used to compute bootstrap confidence intervals.
A numeric vector containing all ordered levels of the
outcome.
Which R function should be used to fit the proportional odds
model. Options are "polr" (from the MASS package),
"vglm" (from the VGAM package), or "clm" (from the ordinal package).
Other options (not currently used).
List with wald and bca-estimated confidence intervals
for the weighted mean parameters.