Compute confidence interval/s for the treatment specific PMF and CDF.
estimate_ci_marg_dist(
marg_cdf_est,
marg_pmf_est,
cdf_est,
pmf_est,
covar,
treat_prob_est,
treat_form,
out_form,
treat,
ci,
out_levels,
out_model,
out,
alpha,
nboot
)Point estimate of treatment-specific CDF.
Point estimate of treatment-specific PMF.
Estimates of treatment-specific conditional CDF.
Estimates of treatment-specific conditional PMF.
A data.frame containing the covariates to include in the working
proportional odds model.
Estimated probability of treatments, output from call
to estimate_treat_prob.
The right-hand side of a regression formula for the working model of treatment probability as a function of covariates
The right-hand side of a regression formula for the working proportional odds model. NOTE: THIS FORMULA MUST NOT SUPPRESS THE INTERCEPT.
A numeric vector containing treatment status. Missing
values are not allowed unless the corresponding entry in out is also missing.
Only values of 0 or 1 are treated as actual treatment levels. Any other value is assumed
to encode a value for which the outcome is missing and the corresponding outcome value is
ignored.
A vector of characters indicating which confidence intervals
should be computed ("bca" and/or "wald")
A numeric vector containing all ordered levels of the
outcome.
Which R function should be used to fit the proportional odds
model. Options are "polr" (from the MASS package),
"vglm" (from the VGAM package), or "clm" (from the ordinal package).
A numeric vector containing the outcomes. Missing outcomes are
allowed.
Confidence intervals have nominal level 1-alpha.
Number of bootstrap replicates used to compute bootstrap confidence intervals.
List of lists (cdf and pmf) with wald and bca-estimated confidence
intervals for the marginal treatment-specific distribution functions.