Compute one estimate of the marginal CDF/PMF on a given data set.
get_one_marg_dist(
treat,
covar,
treat_form,
out_model,
out,
out_levels,
out_form
)A numeric vector containing treatment status. Should only assume
a value 0 or 1.
A data.frame containing the covariates to include in the working
proportional odds model.
The right-hand side of a regression formula for the working model of treatment probability as a function of covariates
Which R function should be used to fit the proportional odds
model. Options are "polr" (from the MASS package),
"vglm" (from the VGAM package), or "clm" (from the ordinal package).
A numeric vector containing the outcomes. Missing outcomes are
allowed.
A numeric vector containing all ordered levels of the
outcome.
The right-hand side of a regression formula for the working proportional odds model. NOTE: THIS FORMULA MUST NOT SUPPRESS THE INTERCEPT.
List of estimated cdf/pmf for these input data.