Get one bootstrap computation of the log odds parameters.
one_boot_logodds(
treat,
covar,
out,
treat_form,
out_levels,
out_form,
out_model
)A numeric vector containing treatment status. Should only assume
a value 0 or 1.
A data.frame containing the covariates to include in the working
proportional odds model.
A numeric vector containing the outcomes. Missing outcomes are
allowed.
The right-hand side of a regression formula for the working model of treatment probability as a function of covariates
A numeric vector containing all ordered levels of the
outcome.
The right-hand side of a regression formula for the working proportional odds model. NOTE: THIS FORMULA MUST NOT SUPPRESS THE INTERCEPT.
Which R function should be used to fit the proportional odds
model. Options are "polr" (from the MASS package),
"vglm" (from the VGAM package), or "clm" (from the ordinal package).
Estimates of log odds for a particular bootstrap sample.