Get one bootstrap computation of the weighted mean parameters.
one_boot_wmean(
treat,
covar,
out,
treat_form,
out_levels,
out_form,
out_weights,
out_model
)A numeric vector containing treatment status. Missing
values are not allowed unless the corresponding entry in out is also missing.
Only values of 0 or 1 are treated as actual treatment levels. Any other value is assumed
to encode a value for which the outcome is missing and the corresponding outcome value is
ignored.
A data.frame containing the covariates to include in the working
proportional odds model.
A numeric vector containing the outcomes. Missing outcomes are
allowed.
The right-hand side of a regression formula for the working model of treatment probability as a function of covariates
A numeric vector containing all ordered levels of the
outcome.
The right-hand side of a regression formula for the working proportional odds model. NOTE: THIS FORMULA MUST NOT SUPPRESS THE INTERCEPT.
A vector of numeric weights with length equal to the length
of out_levels.
Which R function should be used to fit the proportional odds
model. Options are "polr" (from the MASS package),
"vglm" (from the VGAM package), or "clm" (from the ordinal package).
Estimates of weighted mean for a particular bootstrap sample.