Compute confidence interval/s for the Mann-Whitney parameter
estimate_ci_mannwhitney(
mannwhitney_est,
cdf_est,
pmf_est,
treat_prob_est,
treat_form,
out_form,
treat,
ci,
out,
alpha,
nboot,
out_levels,
covar,
out_model
)The point estimates for log-odds.
The estimated conditional CDF.
The estimated conditional PMF.
Estimated probability of treatments, output from call
to estimate_treat_prob.
The right-hand side of a regression formula for the working model of treatment probability as a function of covariates
The right-hand side of a regression formula for the working proportional odds model. NOTE: THIS FORMULA MUST NOT SUPPRESS THE INTERCEPT.
A numeric vector containing treatment status. Missing
values are not allowed unless the corresponding entry in out is also missing.
Only values of 0 or 1 are treated as actual treatment levels. Any other value is assumed
to encode a value for which the outcome is missing and the corresponding outcome value is
ignored.
A vector of characters indicating which confidence intervals
should be computed ("bca" and/or "wald")
A numeric vector containing the outcomes. Missing outcomes are
allowed.
Confidence intervals have nominal level 1-alpha.
Number of bootstrap replicates used to compute bootstrap confidence intervals.
A numeric vector containing all ordered levels of the
outcome.
A data.frame containing the covariates to include in the working
proportional odds model.
Which R function should be used to fit the proportional odds
model. Options are "polr" (from the MASS package),
"vglm" (from the VGAM package), or "clm" (from the ordinal package).
List with wald and bca-estimated confidence intervals
for the Mann-Whitney parameter.